Fix A2DP metrics session duration

* Add one extra item in the A2DPSession message to keep track of audio
  playback time for A2DP source

Bug: 33694310
Test: code compilation
Merged-In: Iee1e47997bf9cf9ba3f7f812c965eab36f19c0f4
Change-Id: Iee1e47997bf9cf9ba3f7f812c965eab36f19c0f4
(cherry picked from commit 4308e8f5f34b668f48cb50fbbdac77e45d04e432)
diff --git a/src/com/android/bluetooth/btservice/bluetooth.proto b/src/com/android/bluetooth/btservice/bluetooth.proto
index 77ded78..871a13a 100644
--- a/src/com/android/bluetooth/btservice/bluetooth.proto
+++ b/src/com/android/bluetooth/btservice/bluetooth.proto
@@ -82,7 +82,7 @@
   // The information about the RFComm session.
   optional RFCommSession rfcomm_session = 6;
 
   // The information about the A2DP session.
   optional A2DPSession a2dp_session = 7;
 }
 
@@ -95,7 +95,7 @@
   optional int32 tx_bytes = 2;
 }
 
-// Session information that gets logged for every A2DP session.
+// Session information that gets logged for A2DP session.
 message A2DPSession {
 
   // Media timer in milliseconds.
@@ -118,6 +118,9 @@
 
   // Buffer underruns count.
   optional int32 buffer_underruns_count = 7;
+
+  // Total audio time in this A2DP session
+  optional int64 audio_duration_millis = 8;
 }
 
 message PairEvent {
@@ -82,7 +82,7 @@
   optional RFCommSession rfcomm_session = 6;
 
-  // The information about the A2DP session.
+  // The information about the A2DP audio session.
   optional A2DPSession a2dp_session = 7;
 }